@@ -122,14 +122,14 @@ void TestItemMarkerTiler::testIndices()
 void TestItemMarkerTiler::testAddMarkers1()
 {
     QScopedPointer<QStandardItemModel> itemModel(new QStandardItemModel());
-    ItemMarkerTiler mm(new MarkerModelHelper(itemModel.data(), 0));
+    ItemMarkerTiler mm(new MarkerModelHelper(itemModel.data(), nullptr));
 
     const int maxLevel = TileIndex::MaxLevel;
 
     // there should be no tiles in the model yet:
     for (int l = 0; l <= maxLevel; ++l)
     {
-        QVERIFY(mm.getTile(TileIndex::fromCoordinates(coord_50_60, l), true) == 0);
+        QVERIFY(mm.getTile(TileIndex::fromCoordinates(coord_50_60, l), true) == nullptr);
     }
 
     itemModel->appendRow(MakeItemAt(coord_50_60));
@@ -139,7 +139,7 @@ void TestItemMarkerTiler::testAddMarkers1()
     {
         const TileIndex tileIndex           = TileIndex::fromCoordinates(coord_50_60, l);
         ItemMarkerTiler::Tile* const myTile = mm.getTile(tileIndex, true);
-        QVERIFY(myTile != 0);
+        QVERIFY(myTile != nullptr);
         QVERIFY(myTile->childrenEmpty());
         QVERIFY(mm.getTileMarkerCount(tileIndex) == 1);
     }
@@ -151,7 +151,7 @@ void TestItemMarkerTiler::testAddMarkers1()
     {
         const TileIndex tileIndex           = TileIndex::fromCoordinates(coord_50_60, l);
         ItemMarkerTiler::Tile* const myTile = mm.getTile(tileIndex, true);
-        QVERIFY(myTile != 0);
+        QVERIFY(myTile != nullptr);
         QCOMPARE(mm.getTileMarkerCount(tileIndex), 2);
     }
 }
@@ -159,7 +159,7 @@ void TestItemMarkerTiler::testAddMarkers1()
 void TestItemMarkerTiler::testRemoveMarkers2()
 {
     QScopedPointer<QStandardItemModel> itemModel(new QStandardItemModel());
-    ItemMarkerTiler mm(new MarkerModelHelper(itemModel.data(), 0));
+    ItemMarkerTiler mm(new MarkerModelHelper(itemModel.data(), nullptr));
 
     const int maxLevel = TileIndex::MaxLevel;
 
@@ -172,7 +172,7 @@ void TestItemMarkerTiler::testRemoveMarkers2()
     {
         const TileIndex tileIndex           = TileIndex::fromCoordinates(coord_50_60, l);
         ItemMarkerTiler::Tile* const myTile = mm.getTile(tileIndex, true);
-        QVERIFY(myTile != 0);
+        QVERIFY(myTile != nullptr);
         QCOMPARE(mm.getTileMarkerCount(tileIndex), 2);
     }
 
@@ -183,7 +183,7 @@ void TestItemMarkerTiler::testRemoveMarkers2()
     {
         const TileIndex tileIndex           = TileIndex::fromCoordinates(coord_50_60, l);
         ItemMarkerTiler::Tile* const myTile = mm.getTile(tileIndex, true);
-        QVERIFY(myTile != 0);
+        QVERIFY(myTile != nullptr);
         QCOMPARE(mm.getTileMarkerCount(tileIndex), 1);
     }
 }
@@ -191,7 +191,7 @@ void TestItemMarkerTiler::testRemoveMarkers2()
 void TestItemMarkerTiler::testMoveMarkers1()
 {
     QScopedPointer<QStandardItemModel> itemModel(new QStandardItemModel());
-    ItemMarkerTiler mm(new MarkerModelHelper(itemModel.data(), 0));
+    ItemMarkerTiler mm(new MarkerModelHelper(itemModel.data(), nullptr));
     const int maxLevel  = TileIndex::MaxLevel;
     const int fillLevel = maxLevel - 2;
 
@@ -206,7 +206,7 @@ void TestItemMarkerTiler::testMoveMarkers1()
     {
         const TileIndex tileIndex           = TileIndex::fromCoordinates(coord_1_2, l);
         ItemMarkerTiler::Tile* const myTile = mm.getTile(tileIndex, true);
-        QVERIFY(myTile != 0);
+        QVERIFY(myTile != nullptr);
         QVERIFY(myTile->childrenEmpty());
         QCOMPARE(mm.getTileMarkerCount(tileIndex), 1);
     }
@@ -218,14 +218,14 @@ void TestItemMarkerTiler::testMoveMarkers1()
     {
         // make sure the marker can not be found at the old position any more
         TileIndex tileIndex = TileIndex::fromCoordinates(coord_1_2, l);
-        QVERIFY(mm.getTile(tileIndex, true) == 0);
+        QVERIFY(mm.getTile(tileIndex, true) == nullptr);
         QCOMPARE(mm.getTileMarkerCount(tileIndex), 0);
-        QVERIFY(mm.getTile(tileIndex, true) == 0);
+        QVERIFY(mm.getTile(tileIndex, true) == nullptr);
 
         // find it at the new position:
         tileIndex                           = TileIndex::fromCoordinates(coord_50_60, l);
         ItemMarkerTiler::Tile* const myTile = mm.getTile(tileIndex, true);
-        QVERIFY(myTile != 0);
+        QVERIFY(myTile != nullptr);
         QVERIFY(myTile->childrenEmpty());
         QVERIFY(mm.getTileMarkerCount(tileIndex) == 1);
     }
@@ -236,7 +236,7 @@ void TestItemMarkerTiler::testMoveMarkers1()
 void TestItemMarkerTiler::testMoveMarkers2()
 {
     QScopedPointer<QStandardItemModel> itemModel(new QStandardItemModel());
-    ItemMarkerTiler mm(new MarkerModelHelper(itemModel.data(), 0));
+    ItemMarkerTiler mm(new MarkerModelHelper(itemModel.data(), nullptr));
     const int maxLevel = TileIndex::MaxLevel;
 
     const int fillLevel = maxLevel - 2;
@@ -253,7 +253,7 @@ void TestItemMarkerTiler::testMoveMarkers2()
     {
         const TileIndex tileIndex           = TileIndex::fromCoordinates(coord_1_2, l);
         ItemMarkerTiler::Tile* const myTile = mm.getTile(tileIndex, true);
-        QVERIFY(myTile != 0);
+        QVERIFY(myTile != nullptr);
         QVERIFY(myTile->childrenEmpty());
         QVERIFY(mm.getTileMarkerCount(tileIndex) == 2);
     }
@@ -266,7 +266,7 @@ void TestItemMarkerTiler::testMoveMarkers2()
     {
         const TileIndex tileIndex           = TileIndex::fromCoordinates(coord_50_60, l);
         ItemMarkerTiler::Tile* const myTile = mm.getTile(tileIndex, true);
-        QVERIFY(myTile != 0);
+        QVERIFY(myTile != nullptr);
         QVERIFY(myTile->childrenEmpty());
         QVERIFY(mm.getTileMarkerCount(tileIndex) == 1);
     }
@@ -286,7 +286,7 @@ void TestItemMarkerTiler::testMoveMarkers2()
         // find it at the new position:
         tileIndex                           = TileIndex::fromCoordinates(coord_50_60, l);
         ItemMarkerTiler::Tile* const myTile = mm.getTile(tileIndex, true);
-        QVERIFY(myTile != 0);
+        QVERIFY(myTile != nullptr);
 
         if (l > fillLevel)
         {
@@ -302,7 +302,7 @@ void TestItemMarkerTiler::testMoveMarkers2()
 void TestItemMarkerTiler::testIteratorWholeWorldNoBackingModel()
 {
     QScopedPointer<QStandardItemModel> itemModel(new QStandardItemModel());
-    ItemMarkerTiler mm(new MarkerModelHelper(itemModel.data(), 0));
+    ItemMarkerTiler mm(new MarkerModelHelper(itemModel.data(), nullptr));
     const int maxLevel = TileIndex::MaxLevel;
 
     for (int l = 0; l <= maxLevel; ++l)
@@ -315,7 +315,7 @@ void TestItemMarkerTiler::testIteratorWholeWorldNoBackingModel()
 void TestItemMarkerTiler::testIteratorWholeWorld()
 {
     QScopedPointer<QStandardItemModel> itemModel(new QStandardItemModel());
-    ItemMarkerTiler mm(new MarkerModelHelper(itemModel.data(), 0));
+    ItemMarkerTiler mm(new MarkerModelHelper(itemModel.data(), nullptr));
     const int maxLevel = TileIndex::MaxLevel;
 
     for (int l = 0; l <= maxLevel; ++l)
@@ -338,7 +338,7 @@ void TestItemMarkerTiler::testIteratorWholeWorld()
 void TestItemMarkerTiler::testIteratorPartial1()
 {
     QScopedPointer<QStandardItemModel> itemModel(new QStandardItemModel());
-    ItemMarkerTiler mm(new MarkerModelHelper(itemModel.data(), 0));
+    ItemMarkerTiler mm(new MarkerModelHelper(itemModel.data(), nullptr));
     const int maxLevel = TileIndex::MaxLevel;
 
     itemModel->appendRow(MakeItemAt(coord_1_2));
@@ -406,7 +406,7 @@ void TestItemMarkerTiler::testIteratorPartial1()
 void TestItemMarkerTiler::testIteratorPartial2()
 {
     QScopedPointer<QStandardItemModel> itemModel(new QStandardItemModel());
-    ItemMarkerTiler mm(new MarkerModelHelper(itemModel.data(), 0));
+    ItemMarkerTiler mm(new MarkerModelHelper(itemModel.data(), nullptr));
     const int maxLevel = TileIndex::MaxLevel;
 
     GeoCoordinates::PairList boundsList;
@@ -433,7 +433,7 @@ void TestItemMarkerTiler::testIteratorPartial2()
 void TestItemMarkerTiler::testRemoveMarkers1()
 {
     QScopedPointer<QStandardItemModel> itemModel(new QStandardItemModel());
-    ItemMarkerTiler mm(new MarkerModelHelper(itemModel.data(), 0));
+    ItemMarkerTiler mm(new MarkerModelHelper(itemModel.data(), nullptr));
     const int maxLevel = TileIndex::MaxLevel;
 
     for (int l = 0; l <= maxLevel; ++l)
@@ -478,7 +478,7 @@ void TestItemMarkerTiler::testPreExistingMarkers()
 {
     QScopedPointer<QStandardItemModel> itemModel(new QStandardItemModel());
     itemModel->appendRow(MakeItemAt(coord_50_60));
-    ItemMarkerTiler mm(new MarkerModelHelper(itemModel.data(), 0));
+    ItemMarkerTiler mm(new MarkerModelHelper(itemModel.data(), nullptr));
 
     const int maxLevel = TileIndex::MaxLevel;
 
@@ -512,7 +512,7 @@ void TestItemMarkerTiler::testSelectionState1()
     {
         const TileIndex tileIndex           = TileIndex::fromCoordinates(coord_50_60, l);
         ItemMarkerTiler::Tile* const myTile = mm.getTile(tileIndex, true);
-        QVERIFY(myTile != 0);
+        QVERIFY(myTile != nullptr);
         QVERIFY(mm.getTileMarkerCount(tileIndex) == 1);
         QVERIFY(mm.getTileGroupState(tileIndex)==SelectedNone);
     }
@@ -524,7 +524,7 @@ void TestItemMarkerTiler::testSelectionState1()
     {
         const TileIndex tileIndex           = TileIndex::fromCoordinates(coord_50_60, l);
         ItemMarkerTiler::Tile* const myTile = mm.getTile(tileIndex, true);
-        QVERIFY(myTile != 0);
+        QVERIFY(myTile != nullptr);
         QCOMPARE(mm.getTileMarkerCount(tileIndex), 1);
         QVERIFY(mm.getTileGroupState(tileIndex)==SelectedAll);
         QVERIFY(mm.getTileSelectedCount(tileIndex)==1);
@@ -540,7 +540,7 @@ void TestItemMarkerTiler::testSelectionState1()
     {
         const TileIndex tileIndex           = TileIndex::fromCoordinates(coord_50_60, l);
         ItemMarkerTiler::Tile* const myTile = mm.getTile(tileIndex, true);
-        QVERIFY(myTile != 0);
+        QVERIFY(myTile != nullptr);
         QCOMPARE(mm.getTileMarkerCount(tileIndex), 2);
         QVERIFY(mm.getTileGroupState(tileIndex)==SelectedSome);
         QCOMPARE(mm.getTileSelectedCount(tileIndex), 1);
@@ -552,7 +552,7 @@ void TestItemMarkerTiler::testSelectionState1()
     {
         const TileIndex tileIndex           = TileIndex::fromCoordinates(coord_50_60, l);
         ItemMarkerTiler::Tile* const myTile = mm.getTile(tileIndex, true);
-        QVERIFY(myTile != 0);
+        QVERIFY(myTile != nullptr);
         QCOMPARE(mm.getTileMarkerCount(tileIndex), 2);
         QCOMPARE(mm.getTileSelectedCount(tileIndex), 2);
         QVERIFY(mm.getTileGroupState(tileIndex)==SelectedAll);
@@ -567,7 +567,7 @@ void TestItemMarkerTiler::testSelectionState1()
     {
         const TileIndex tileIndex           = TileIndex::fromCoordinates(coord_50_60, l);
         ItemMarkerTiler::Tile* const myTile = mm.getTile(tileIndex, true);
-        QVERIFY(myTile != 0);
+        QVERIFY(myTile != nullptr);
         QCOMPARE(mm.getTileMarkerCount(tileIndex), 1);
         QCOMPARE(mm.getTileSelectedCount(tileIndex), 1);
         QVERIFY(mm.getTileGroupState(tileIndex)==SelectedAll);
@@ -584,7 +584,7 @@ void TestItemMarkerTiler::testSelectionState1()
     {
         const TileIndex tileIndex           = TileIndex::fromCoordinates(coord_1_2, l);
         ItemMarkerTiler::Tile* const myTile = mm.getTile(tileIndex, true);
-        QVERIFY(myTile != 0);
+        QVERIFY(myTile != nullptr);
         QCOMPARE(mm.getTileMarkerCount(tileIndex), 1);
         QCOMPARE(mm.getTileSelectedCount(tileIndex), 1);
         QVERIFY(mm.getTileGroupState(tileIndex)==SelectedAll);
@@ -594,7 +594,7 @@ void TestItemMarkerTiler::testSelectionState1()
     {
         const TileIndex tileIndex           = TileIndex::fromCoordinates(coord_50_60, l);
         ItemMarkerTiler::Tile* const myTile = mm.getTile(tileIndex, true);
-        QVERIFY(myTile != 0);
+        QVERIFY(myTile != nullptr);
         QCOMPARE(mm.getTileMarkerCount(tileIndex), 1);
         QCOMPARE(mm.getTileSelectedCount(tileIndex), 1);
         QVERIFY(mm.getTileGroupState(tileIndex)==SelectedAll);
@@ -606,7 +606,7 @@ void TestItemMarkerTiler::testSelectionState1()
     {
         const TileIndex tileIndex           = TileIndex::fromCoordinates(coord_50_60, l);
         ItemMarkerTiler::Tile* const myTile = mm.getTile(tileIndex, true);
-        QVERIFY(myTile != 0);
+        QVERIFY(myTile != nullptr);
         QCOMPARE(mm.getTileMarkerCount(tileIndex), 2);
         QCOMPARE(mm.getTileSelectedCount(tileIndex), 2);
         QVERIFY(mm.getTileGroupState(tileIndex)==SelectedAll);
@@ -618,7 +618,7 @@ void TestItemMarkerTiler::testSelectionState1()
     {
         const TileIndex tileIndex           = TileIndex::fromCoordinates(coord_50_60, l);
         ItemMarkerTiler::Tile* const myTile = mm.getTile(tileIndex, true);
-        QVERIFY(myTile != 0);
+        QVERIFY(myTile != nullptr);
         QCOMPARE(mm.getTileMarkerCount(tileIndex), 1);
         QCOMPARE(mm.getTileSelectedCount(tileIndex), 1);
         QVERIFY(mm.getTileGroupState(tileIndex)==SelectedAll);
@@ -628,7 +628,7 @@ void TestItemMarkerTiler::testSelectionState1()
     {
         const TileIndex tileIndex           = TileIndex::fromCoordinates(coord_m50_m60, l);
         ItemMarkerTiler::Tile* const myTile = mm.getTile(tileIndex, true);
-        QVERIFY(myTile != 0);
+        QVERIFY(myTile != nullptr);
         QCOMPARE(mm.getTileMarkerCount(tileIndex), 1);
         QCOMPARE(mm.getTileSelectedCount(tileIndex), 1);
         QVERIFY(mm.getTileGroupState(tileIndex)==SelectedAll);
